@@ -78,8 +78,13 @@ class InitConnectionPool:
                                                             fromlist="SqlAlchemyPool")
                         # 执行用例
                         pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "nebula":
+                        clazz = InitConnectionPool.getClass("lesscode.db.nebula.nebula_pool",
+                                                            fromlist="NebulaPool")
+                        # 执行用例
+                        pool = clazz(conn_info).create_pool()
                     if pool:
-                        options.database[conn_info.name] = (pool, conn_info.dialect)
+                        options.database[conn_info.name] = (pool, conn_info)
 
     @staticmethod
     def sync_create_pool():
@@ -141,8 +146,13 @@ class InitConnectionPool:
                                                             fromlist="SqlAlchemyPool")
                         # 执行用例
                         pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "nebula":
+                        clazz = InitConnectionPool.getClass("lesscode.db.nebula.nebula_pool",
+                                                            fromlist="NebulaPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
                     if pool:
-                        options.database[conn_info.name] = (pool, conn_info.dialect)
+                        options.database[conn_info.name] = (pool, conn_info)
 
     @staticmethod
     def getClass(name, fromlist):
